import * as React_2 from 'react';

declare type ILazyContainerProps = {
    /**
     * Container React children
     */
    children: React_2.ReactElement;
    /**
     * Tag name for the DOM node added by container
     */
    as?: keyof JSX.IntrinsicElements;
    /**
     * Intersection Observer options
     */
    options: IntersectionObserverInit;
};

declare type ILazyImageProps = {
    /**
     * Item React children
     */
    children: React_2.ReactElement;
    /**
     * Tag name for the DOM node added by Item
     */
    as?: keyof JSX.IntrinsicElements;
    /**
     * Default Image height
     */
    height?: number;
    /**
     * Default Image width
     */
    width?: number;
    /**
     * Image source URL
     */
    src: string;
    /**
     * Image source URL
     */
    alt: string;
    /**
     * transition duration in seconds
     */
    transitionDuration: number;
    /**
     * transition duration in seconds
     */
    position: string;
};

declare type ILazyItemProps = {
    /**
     * Item React children
     */
    children: React_2.ReactElement;
    /**
     * Tag name for the DOM node added by Item
     */
    as?: keyof JSX.IntrinsicElements;
    /**
     * Control visibility logic
     */
    changeWhen?: (visibility: boolean) => boolean;
    /**
     * Control default visibility; default is set to false
     */
    defaultVisibility?: boolean;
};

declare interface ILazyPlaceholderProps extends React_2.HTMLAttributes<HTMLOrSVGElement> {
    as: keyof JSX.IntrinsicElements;
}

export declare const Lazy: {
    /**
     * Lazy Container - It adds single Intersection Observer for Items
     */
    Container: typeof LazyContainer;
    /**
     * Lazy Item - It use nearest Lazy.Container's Intersection Observer to controll the visibility of its children
     */
    Item: typeof LazyItem;
    /**
     * Lazy Placeholder - Anything children inside Placeholder is shown till the time nearest Lazy.Item visibility is false
     */
    Placeholder: typeof LazyPlaceHolder;
    /**
     * Lazy image - A basic lazy loaded transition image by controlling opacity
     */
    Image: typeof LazyImage;
};

declare function LazyContainer({ children, as, options }: ILazyContainerProps): JSX.Element;

declare function LazyImage({ as, src, transitionDuration, children, height, width, alt, position, ...restProps }: ILazyImageProps): JSX.Element;

declare function LazyItem({ as, children, defaultVisibility, changeWhen, ...restProps }: ILazyItemProps): JSX.Element;

declare type LazyItemOptions = {
    /**
     * Control default visibility; default is set to false
     */
    defaultVisibility?: boolean;
    /**
     * Callback when then visibility change to true
     */
    onChange?: () => void;
};

declare function LazyPlaceHolder({ as, children, ...props }: ILazyPlaceholderProps): JSX.Element;

/**
 * React hook for LazyItem for more granular control.
 */
export declare function useLazyItem({ defaultVisibility, onChange, }?: LazyItemOptions): {
    visible: boolean;
    ref: React_2.MutableRefObject<Element>;
};

export { }
